@@ -1,8 +1,8 @@
 package PNI::Item;
 use strict;
 use warnings;
-our $VERSION = '0.12';
-use PNI::Error;
+our $VERSION = '0.14';
+use PNI::Error 0.14;
 
 my $next_id;
 
@@ -15,25 +15,6 @@ sub new {
     return bless \$item_id, $class;
 }
 
-sub id {
-    my $self = shift;
-    return $$self;
-}
-
-sub cleanup {
-    my $self = shift;
-    my $id   = $self->id;
-
-    for my $attribute_name ( keys %{ $attr{$id} } ) {
-        delete $attr{$id}{$attribute_name};
-    }
-
-    return 1;
-}
-
-# init is abstract ...
-sub init { return PNI::Error::unimplemented_abstract_method; }
-
 sub add {
     my $self = shift;
     my $id   = $self->id;
@@ -51,6 +32,17 @@ sub add {
     return 1;
 }
 
+sub cleanup {
+    my $self = shift;
+    my $id   = $self->id;
+
+    for my $attribute_name ( keys %{ $attr{$id} } ) {
+        delete $attr{$id}{$attribute_name};
+    }
+
+    return 1;
+}
+
 sub del {
     my $self           = shift;
     my $id             = $self->id;
@@ -60,11 +52,27 @@ sub del {
     return 1;
 }
 
-sub set {
-    my $self = shift;
-    my $id   = $self->id;
+sub get {
+    my $self           = shift;
+    my $attribute_name = shift or return PNI::Error::missing_required_argument;
+    my $id             = $self->id;
 
-    my $attribute_name = shift or return;
+    exists $attr{$id}{$attribute_name} or return;
+
+    return $attr{$id}{$attribute_name};
+}
+
+sub id {
+    my $self = shift;
+    return ${$self};
+}
+
+sub init { return PNI::Error::unimplemented_abstract_method; }
+
+sub set {
+    my $self           = shift;
+    my $attribute_name = shift or return PNI::Error::missing_required_argument;
+    my $id             = $self->id;
 
     # check if attribute exists
     exists $attr{$id}{$attribute_name} or return;
@@ -77,14 +85,6 @@ sub set {
     return 1;
 }
 
-sub get {
-    my $self           = shift;
-    my $id             = $self->id;
-    my $attribute_name = shift or return;
-    exists $attr{$id}{$attribute_name} or return;
-    return $attr{$id}{$attribute_name};
-}
-
 sub DESTROY {
 
     # garbage all item attributes
@@ -92,3 +92,23 @@ sub DESTROY {
 }
 
 1;
+
+=head1 NAME
+
+PNI::Item - is the base class
+
+
+
+
+=head1 AUTHOR
+
+G. Casati , E<lt>fibo@cpan.orgE<gt>
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright (C) 2009-2011, Gianluca Casati
+
+This program is free software, you can redistribute it and/or modify it
+under the same terms of the Artistic License version 2.0 .
+
+=cut
