@@ -1,44 +1,19 @@
 package PNI::Node;
 use strict;
 use warnings;
-our $VERSION = '0.12';
+our $VERSION = '0.14';
 use base 'PNI::Item';
-use PNI::Error;
-use PNI::Slot::In;
-use PNI::Slot::Out;
+use PNI::Error 0.14;
+use PNI::Slot::In 0.14;
+use PNI::Slot::Out 0.14;
 
 sub new {
+    my $class = shift;
+    my $arg   = {@_};
 
-    # ignore the first parameter since the node class depends
-    # on type parameter, see below
-    shift;    # my $class
-
-    # $arg can be empty if you want an empty node
-    my $arg = {@_};
-
-    # type parameter is optional
-    my $type = $arg->{type};
-    my $class;
-
-    # if a type is specified, try to require the corresponding class
-    if ( defined $type ) {
-        $class = __PACKAGE__ . '::' . $type;
-        ( my $path = $class . '.pm' ) =~ s=::=/=g;
-        eval { require $path } or return;
-    }
-
-    # otherwise build a generic empty node you can decorate later
-    else {
-        $class = __PACKAGE__;
-    }
-
-    # seems better than $class->SUPER::new
     my $self = PNI::Item::new($class);
-    $self->add( 'inputs'  => {} );
-    $self->add( 'outputs' => {} );
-
-    # at this point the node is created, so you can initialize it
-    $self->init or return;
+    $self->add( inputs  => {} );
+    $self->add( outputs => {} );
 
     return $self;
 }
@@ -67,9 +42,6 @@ sub add_output {
     return $output;
 }
 
-sub del_input  { return 1; }
-sub del_output { return 1; }
-
 sub get_input {
     my $self = shift;
     my $input_name = shift or return PNI::Error::missing_required_argument;
@@ -86,45 +58,60 @@ sub get_inputs { return values %{ shift->get('inputs') }; }
 
 sub get_outputs { return values %{ shift->get('outputs') }; }
 
-sub get_input_links {
+sub get_input_edges {
     my $self        = shift;
-    my @input_links = ();
+    my @input_edges = ();
     for my $input ( $self->get_inputs ) {
-        my $link = $input->get_link;
-        if ( defined $link ) {
-            push @input_links, $link;
+        my $edge = $input->get_edge;
+        if ( defined $edge ) {
+            push @input_edges, $edge;
         }
     }
-    return @input_links;
+    return @input_edges;
 }
 
-sub get_output_links {
+sub get_output_edges {
     my $self         = shift;
-    my @output_links = ();
+    my @output_edges = ();
     for my $output ( $self->get_outputs ) {
-        my @links = $output->get_links;
-        if (@links) {
-            push @output_links, @links;
+        my @edges = $output->get_edges;
+        if (@edges) {
+            push @output_edges, @edges;
         }
     }
-    return @output_links;
+    return @output_edges;
 }
 
 sub init { return 1; }
-sub task { return 1; }
+sub task { return PNI::Error::unimplemented_abstract_method; }
 
 1;
 
 =head1 NAME
 
-PNI::Node
+PNI::Node - is a basic unit of code
+
+
 
 =head1 DESCRIPTION
 
-Basic unit of code . This class has an init method called at creation and a task method called at every PNI::RUN .
+This is an abstract class: it has an init method called after creation and a task method called at every PNI::step.
 
 =head1 SEE ALSO
 
-<PNI::Link>
+L<PNI::Link>
+
+
+
+=head1 AUTHOR
+
+G. Casati , E<lt>fibo@cpan.orgE<gt>
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright (C) 2009-2011, Gianluca Casati
+
+This program is free software, you can redistribute it and/or modify it
+under the same terms of the Artistic License version 2.0 .
 
 =cut
